//archer HUD

#include "ArcherCommon.as";
#include "ActorHUDStartPos.as";

const string iconsFilename = "Entities/Characters/Archer/ArcherIcons.png";
const int slotsSize = 5;

void onInit( CSprite@ this )
{
	this.getCurrentScript().runFlags |= Script::tick_myplayer;
	this.getCurrentScript().removeIfTag = "dead";
	this.getBlob().set_u8("gui_HUD_slots_width", slotsSize);
}

void ManageCursors( CBlob@ this )
{
	CHUD@ hud = getHUD();
	// set cursor
	if (hud.hasButtons()) {
		hud.SetDefaultCursor();
	}
	else
	{
		// set cursor
		hud.SetCursorImage("Entities/Characters/Archer/ArcherCursor.png", Vec2f(32,32));
		hud.SetCursorOffset( Vec2f(-32, -32) );
		
		ArcherInfo@ archer;
		if (!this.get( "archerInfo", @archer )) {
			return;
		}

		if( archer.charge_state == ArcherParams::readying){
			hud.SetCursorFrame(1);
		} else if( archer.charge_state == ArcherParams::charging || 
			archer.charge_state == ArcherParams::decharging ){
			//print(""+ archer.charge_time);
			//int frame = Maths::Min(1 + archer.charge_time*7*3/2/ArcherParams::shoot_period, 8);
			int frame = Maths::Min(2 + archer.charge_time*9/ArcherParams::shoot_period, 8); 			
			hud.SetCursorFrame(frame);
		} else
			hud.SetCursorFrame(0);
	}
}

void onRender( CSprite@ this )
{
	if (g_videorecording)
		return;

	CBlob@ blob = this.getBlob();
	CPlayer@ player = blob.getPlayer();

	ManageCursors( blob );

	// draw inventory

	Vec2f tl = getActorHUDStartPosition(blob, slotsSize);
	DrawInventoryOnHUD( blob, tl );

	const u8 type = getArrowType( blob );
	u8 arrow_frame = 0;
	if (type != ArrowType::normal){
		arrow_frame = 2 + type;
	}

	// draw coins

	const int coins = player !is null ? player.getCoins() : 0;
	DrawCoinsOnHUD( blob, coins, tl, slotsSize-2 );
	
	// class weapon icon

	GUI::DrawIcon( iconsFilename, arrow_frame, Vec2f(16,32), tl+Vec2f(8 + (slotsSize-1)*32,-16), 1.0f);
}
